With some new commits I just made, the time to build a standard checkout from scratch is now down to: real 1m16.348s user 2m44.714s sys 1m11.761s make -j now properly parallelizes the module builds as well. More to come. Mike
-----Original Message----- I have been working on many build improvements to the FreeSWITCH(tm) build system as you know. The most common complaint I have had lately is how long it takes to ./bootstrap.sh && ./configure && make. I have a few things in place to address this now. Please read on.
<snip>
Build speed test machine specs: Dual Intel(R) Xeon(R) CPU 5130 @ 2.00GHz server (4mb cache) 8gb ram RHEL 4 gcc (GCC) 3.4.6 20060404 (Red Hat 3.4.6-3) clean checkout of svn trunk r4844 bootstrapped using: autoconf (GNU Autoconf) 2.59 automake (GNU automake) 1.9.2 ltmain.sh (GNU libtool) 1.5.22 (1.1220.2.436 2007/02/17 08:23:50)
(this
is actually 1.5.23b as available on the gnu website at http://www.gnu.org/software/libtool/ under Development Release of Stable Branch GNU Libtool 1.5.23b 17 February 2007 )
configured with no special options but -C and --prefix default modules.conf
time for the make portion only with -j
real 1m33.478s user 2m54.077s sys 1m16.572s
time for the make portion only without -j
real 4m2.703s user 2m48.403s sys 1m16.136s